<?php
/**
 * @file
 * ExtraWatch - Real-time Visitor Analytics and Stats
 * @package ExtraWatch
 * @version 4.0
 * @revision 30
 * @license http://www.gnu.org/licenses/gpl-3.0.txt     GNU General Public License v3
 * @copyright (C) 2018 by CodeGravity.com - All rights reserved!
 * @website http://www.extrawatch.com
 */

require("ExtraWatchCMSSpecific.php");

class ExtraWatchJoomlaSpecific implements ExtraWatchCMSSpecific {


    private $db;

    const EW_TABLE_SETTINGS = '#__extrawatch_settings';

    const EW_COLUMN_KEY = 'key';
    const EW_COLUMN_VALUE = 'value';

    public function __construct() {
        $this->db = JFactory::getDbo();
    }

    public function getPlatformIdentifier() {
        return ExtraWatchCMSEnum::JOOMLA;
    }

    public function getCMSURL() {
        return str_replace("/administrator","", JURI::base());
    }

    /* project Id */
    public function getPluginOptionProjectId() {
        return $this->getValue(EXTRAWATCH_SETTING_PROJECT_ID);
    }

    public function savePluginOptionProjectId($value) {
        $this->insertValueIntoTable(EXTRAWATCH_SETTING_PROJECT_ID, $value);
    }

    public function deletePluginOptionProjectId() {
    }
    /* project Id */



    /* temp pwd */
    public function getPluginOptionTempPassword() {
        return $this->getValue(EXTRAWATCH_SETTING_TEMP_PASSWORD);
    }

    public function savePluginOptionTempPassword($value) {
        $this->insertValueIntoTable(EXTRAWATCH_SETTING_TEMP_PASSWORD, $value);
    }

    public function deleteOptionTempPassword() {
    }
    /* temp pwd */


    private function getValue($key) {
        $query = $this->db->getQuery(true);
        $query->select($this->db->quoteName(self::EW_COLUMN_VALUE));
        $query->from($this->db->quoteName(self::EW_TABLE_SETTINGS));
        $query->where($this->db->quoteName(self::EW_COLUMN_KEY).' = '. $this->db->quote($key));
        $this->db->setQuery($query,0,1);
        $result = $this->db->loadResult();
        return $result;
    }


    public function insertValueIntoTable($key, $value) {
        $this->deleteKey($key);
        $query = $this->db->getQuery(true);
        $columns = array(self::EW_COLUMN_KEY, self::EW_COLUMN_VALUE);
        $values = array($this->db->quote($key), $this->db->quote($value));

        $query
            ->insert($this->db->quoteName(self::EW_TABLE_SETTINGS))
            ->columns($this->db->quoteName($columns))
            ->values(implode(',', $values));

        $this->db->setQuery($query);
        $this->db->execute();
    }

    private function deleteKey($key) {
        $query = $this->db->getQuery(true);

        $conditions = array(
            $this->db->quoteName(self::EW_COLUMN_KEY) . ' = '. $this->db->quote($key),
        );

        $query->delete($this->db->quoteName(self::EW_TABLE_SETTINGS));
        $query->where($conditions);

        $this->db->setQuery($query);
        $this->db->execute();
    }


    public function getPluginOptionToken()
    {
        return $this->getValue(EXTRAWATCH_OAUTH2_TOKEN);
    }

    public function getPluginOptionEmail()
    {
        return $this->getValue(EXTRAWATCH_SETTING_EMAIL);
    }

    public function getPluginOptionTerms()
    {
        return $this->getValue(EXTRAWATCH_SETTING_TERMS);
    }

    public function getPluginOptionURL()
    {
        return $this->getValue(EXTRAWATCH_SETTING_URL);
    }

    public function savePluginOptionToken($value)
    {
        $this->insertValueIntoTable(EXTRAWATCH_OAUTH2_TOKEN, $value);
    }

    public function savePluginOptionEmail($value)
    {
        $this->insertValueIntoTable(EXTRAWATCH_SETTING_EMAIL, $value);
    }

    public function savePluginOptionTerms($value)
    {
        $this->insertValueIntoTable(EXTRAWATCH_SETTING_TERMS, $value);
    }

    public function savePluginOptionURL($value)
    {
        $this->insertValueIntoTable(EXTRAWATCH_SETTING_URL, $value);
    }

    public function deletePluginOptionToken()
    {

    }

    public function getAdminEmail()
    {
        $config=new JConfig();

        return $config->mailfrom;
    }

    public function isAdmin()
    {
        $app = JFactory::getApplication();
        return $app->isAdmin();
    }

    public function getComponentPath()
    {
        return "administrator/index.php?option=com_extrawatch";
    }
}